@@ -569,7 +569,7 @@ mod tests {
             Ready(Some(Err(err))) => {
                 assert!(err.is_http_stream_error());
                 let description = format!("{}", err.source().unwrap());
-                assert!(description.contains("read error"), description);
+                assert!(description.contains("read error"), "{}", description);
             }
             res => panic!("expected HttpStream error, got {:?}", res),
         }
@@ -582,7 +582,7 @@ mod tests {
             Ready(Some(Err(err))) => {
                 assert!(err.is_http_stream_error());
                 let description = format!("{}", err.source().unwrap());
-                assert!(description.contains("read error"), description);
+                assert!(description.contains("read error"), "{}", description);
             }
             res => panic!("expected HttpStream error, got {:?}", res),
         }
@@ -600,7 +600,7 @@ mod tests {
             Ready(Some(Err(err))) => {
                 assert!(err.is_http_stream_error());
                 let description = format!("{}", err.source().unwrap());
-                assert!(description.contains("read error"), description);
+                assert!(description.contains("read error"), "{}", description);
             }
             res => panic!("expected HttpStream error, got {:?}", res),
         }
@@ -687,7 +687,7 @@ mod tests {
         let mut cx = Context::from_waker(&waker);
         match s.poll_next_unpin(&mut cx) {
             Poll::Ready(None) => (),
-            Poll::Ready(Some(event)) => panic!(format!("expected eof, got {:?}", event)),
+            Poll::Ready(Some(event)) => panic!("expected eof, got {:?}", event),
             Poll::Pending => panic!("expected eof, got Pending"),
         }
     }
@@ -700,7 +700,7 @@ mod tests {
         let mut cx = Context::from_waker(&waker);
         match s.poll_next_unpin(&mut cx) {
             Poll::Ready(Some(Ok(event))) => event,
-            Poll::Ready(Some(Err(e))) => panic!(format!("expected eof, got error: {:?}", e)),
+            Poll::Ready(Some(Err(e))) => panic!("expected eof, got error: {:?}", e),
             Poll::Ready(None) => panic!("expected event, got eof"),
             Poll::Pending => panic!("expected event, got Pending"),
         }
